# fastatocsv

fastatocsv is a python package that allows for manipulation of fasta files into csv formats. 
You can access it at (https://pypi.org/project/fastatoscsvconverter/).

## Installation
Use ***```pip install fastatocsv```*** to install the package locally.


### Example
```
import fastatocsv 
fastatocsv.converter.convert("pathtoyourfasta.fasta","new.csv")
```

